@@ -15,8 +15,9 @@
 
 from .network import NetworkView  # NOQA
 from .network_default_route import NetworkSetDefaultRouteView  # NOQA
-from .network_configure_interface import NetworkConfigureInterfaceView, NetworkConfigureWLANView  # NOQA
+from .network_configure_interface import NetworkConfigureInterfaceView  # NOQA
 from .network_configure_ipv4_interface import NetworkConfigureIPv4InterfaceView  # NOQA
+from .network_configure_wlan_interface import NetworkConfigureWLANView  # NOQA
 from .network_bond_interfaces import NetworkBondInterfacesView  # NOQA
 from .welcome import CoreWelcomeView as WelcomeView  # NOQA
 from .login import LoginView  # NOQA
